ScalarValue

Struct ScalarValue 

pub struct ScalarValue<C: Curve> {
    inner: C::Uint,
}
Integer values within the range of a given Curve’s scalar modulus.

This type provides a baseline level of scalar arithmetic functionality which is always available for all curves.

serde support

When the optional serde feature of this create is enabled, [Serialize] and [Deserialize] impls are provided for this type.

The serialization is a fixed-width big endian encoding. When used with textual formats, the binary data is encoded as hexadecimal.

Fields

inner: C::Uint

Inner unsigned integer type.

Implementations

Source

impl<C> ScalarValue<C>
where C: Curve,

pub const ZERO: Self

Zero scalar.

pub const ONE: Self

Multiplicative identity.

pub const MODULUS: Odd<C::Uint> = C::ORDER

Scalar modulus.

pub fn new(uint: C::Uint) -> CtOption<Self>

Create a new scalar from Curve::Uint.

pub fn from_bytes(bytes: &FieldBytes<C>) -> CtOption<Self>

Decode ScalarValue from a serialized field element

pub fn from_slice(slice: &[u8]) -> Result<Self>

Decode ScalarValue from a big endian byte slice.

Errors
pub fn as_uint(&self) -> &C::Uint

Borrow the inner C::Uint.

pub fn as_limbs(&self) -> &[Limb]

Borrow the inner limbs as a slice.

pub fn is_zero(&self) -> Choice

Is this ScalarValue value equal to zero?

pub fn is_even(&self) -> Choice

Is this ScalarValue value even?

pub fn is_odd(&self) -> Choice

Is this ScalarValue value odd?

pub fn to_bytes(&self) -> FieldBytes<C>

Encode ScalarValue as a serialized field element.

pub fn to_uint(&self) -> C::Uint

Convert to a C::Uint.

pub fn random<R: CryptoRng + ?Sized>(rng: &mut R) -> Self

👎Deprecated since 0.14.0: use the Generate trait instead

Deprecated: Generate a random ScalarValue.

Source

impl<C> ScalarValue<C>
where C: CurveArithmetic,

pub(super) fn to_scalar(self) -> Scalar<C>

Convert ScalarValue into a given curve’s scalar type.